#%% Running digits code from example
# Importing kepler-mapper from http://github.com/MLWave/kepler-mapper
import km

# Load digits data
from sklearn import datasets
data, labels = datasets.load_digits().data, datasets.load_digits().target

# Initialize mapper
mapper = km.KeplerMapper(verbose=2)

# Fit and transform data. Definition of km.fit_transform():
# def fit_transform(self, X, projection="sum", scaler=preprocessing.MinMaxScaler())
# Reducer: manifold.TSNE() reduces to default 2 dimentions
# Using default preprocessing.MinMaxScaler()

# TSNE - It converts similarities between data points to joint probabilities and tries
# to minimize the Kullback-Leibler divergence between the joint probabilities of 
# the low-dimensional embedding and the high-dimensional data. 
transformed_data = mapper.fit_transform(data, projection=km.manifold.TSNE()) # show TSNE

# Create the graph. Definition of km.map():
# def map(self, projected_X, inverse_X=None, clusterer=cluster.DBSCAN(eps=0.5,min_samples=3), nr_cubes=10, overlap_perc=0.1):
complex = mapper.map(projected_X=transformed_data,
                     clusterer=km.cluster.DBSCAN(eps=0.3, min_samples=15),
                     nr_cubes=35, overlap_perc=0.9)

# Create the visualizations (increased the graph_gravity for a tighter graph-look.)

#  def visualize(self, complex, color_function="", path_html="mapper_visualization_output.html", title="My Data", 
#          graph_link_distance=30, graph_gravity=0.1, graph_charge=-120, custom_tooltips=None, width_html=0, 
#          height_html=0, show_tooltips=True, show_title=True, show_meta=True)
# Color function: default distance_to_origin
# Tooltips with the target y-labels for every cluster member
mapper.visualize(complex, path_html='C:\Users\Svetlana\Desktop\my_mapper\\digits_ylabel_tooltips.html',
                 title="Digits", graph_gravity=0.25, custom_tooltips=labels)

# SWITCH TO PRESENTATION

#%% PLASMIDS
from sklearn.decomposition import TruncatedSVD

# Loading plasmid data. Data stored in numpy sparse format
data = km.np.load('plasmids_all_ones_zeros_sparse_transposed.npy')[()]
# Labels for subgroups 1-4
labels = km.np.loadtxt('plasmids_subgroup_numbers.csv', delimiter=',')

"""
Data: 831 plasmids by 81898 features, sparse format
""" 
data.A
data.shape

# Reduce dimenssions of data because TSNE() requires number of dimensions to be less than 100.
svd = TruncatedSVD(n_components=90, random_state=42)
new_data = svd.fit_transform(data)

# Initialize
mapper = km.KeplerMapper(verbose=1)

# Fit to and transform the data
projection=km.manifold.TSNE()
projected_data = mapper.fit_transform(new_data, projection=projection)

# Create dictionary called 'complex' with nodes, edges and meta-information
overlap_perc = 0.1
complex = mapper.map(projected_X=projected_data,
					 clusterer=km.cluster.DBSCAN(eps=0.5, min_samples=3), 
					 nr_cubes=20, overlap_perc=overlap_perc)
path_html="C:\Users\Svetlana\Desktop\my_mapper\plasmids_TSNE_DBSCAN_overlap_" +str(overlap_perc)+".html"
mapper.visualize(complex, path_html=path_html, title="831 Plasmids, overlap="+str(overlap_perc), 
                 color_function="average_signal_cluster", graph_gravity=0.30, custom_tooltips=labels)


nodes = (complex['nodes']).values()

